/* -*- Mode: IDL; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is Bradley Baetz
 * Portions created by the Initial Developer are Copyright (C) 2001, 2002
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): Bradley Baetz <bbaetz@student.usyd.edu.au>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or 
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"

/** This interface allows setting the output format for a directory listing
 * Implementations of this interface should default to html, since that is the
 * lowest common denominator which all places can deal with.
 */
[scriptable, uuid(a465d8ed-3661-483d-a6f1-a82a6bd617b3)]
interface nsIDirectoryListing : nsISupports {
    /** Use the pref */
    const unsigned long FORMAT_PREF = 0;
    
    /** Raw format - exactly what comes off the network. It is very
     * unlikely that you want this
     */
    const unsigned long FORMAT_RAW = 1;

    /** HTML */
    const unsigned long FORMAT_HTML = 2;
    
    /** application/http-index-format
     * This will end up at the code in xpfe/components/directory so if
     * you explicitly set this, be sure that this dependancy is OK
     */
    const unsigned long FORMAT_HTTP_INDEX = 3;

    /** The actual format
     * If the given format is not supported, NS_ERROR_FAILURE is returned.
     * The getter for this returns the actual value, having translated
     * FORMAT_PREF into the current pref format
     */
    attribute unsigned long listFormat;
};
