/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator client code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or 
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef nsIWebShellWindow_h__
#define nsIWebShellWindow_h__

#include "nsISupports.h"

/* Forward declarations.... */
class nsIWebShell;
class nsIWidget;
class nsString;
class nsIDOMWindowInternal; 

// Interface ID for nsIWebShellWindow
#define NS_IWEBSHELL_WINDOW_IID \
 { 0x28dce479, 0xbf73, 0x11d2, { 0x96, 0xc8, 0x0, 0x60, 0xb0, 0xfb, 0x99, 0x56}}

class nsIWebShellWindow : public nsISupports
{
public:
  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IWEBSHELL_WINDOW_IID)

  NS_IMETHOD Show(PRBool aShow) = 0;
  NS_IMETHOD ShowModal() = 0;
  NS_IMETHOD Toolbar() = 0;
  NS_IMETHOD Close() = 0;
  NS_IMETHOD GetWebShell(nsIWebShell *& aWebShell) = 0;
  NS_IMETHOD GetContentWebShell(nsIWebShell **aResult) = 0;
  NS_IMETHOD GetWidget(nsIWidget *& aWidget) = 0;
  NS_IMETHOD GetDOMWindow(nsIDOMWindowInternal** aDOMWindow) = 0;
  NS_IMETHOD ConvertWebShellToDOMWindow(nsIWebShell* aShell, nsIDOMWindowInternal** aDOMWindow) = 0;
  NS_IMETHOD LockUntilChromeLoad() = 0;
  NS_IMETHOD GetLockedState(PRBool& aResult) = 0;

  /**
   * Useful only during window initialization, this method knows whether
   * the window should try to load a default page, or just wait for
   * further instructions.
   * @param aYes returns PR_TRUE iff a default page should be loaded.
   * @return always NS_OK
   */
  NS_IMETHOD ShouldLoadDefaultPage(PRBool *aYes) = 0;
};


#endif /* nsIWebShellWindow_h__ */
