/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Jeff Tsai <jt95070@netscape.net>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or 
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "MailNewsTypes2.idl"

interface nsIMsgWindow;
interface nsIMsgFolder;
interface nsIMimeHeaders;

typedef long EDisposeType;
typedef long ReceiptHdrType;
typedef long MDNIncorporateType;

%{C++
#define NS_MSGMDNGENERATOR_CONTRACTID \
  "@mozilla.org/messenger-mdn/generator;1"

#define NS_MSGMDNGENERATOR_CID                    \
{ /* ec917b13-8f73-4d4d-9146-d7f7aafe9076 */      \
 0xec917b13, 0x8f73, 0x4d4d,                      \
 { 0x91, 0x46, 0xd7, 0xf7, 0xaa, 0xfe, 0x90, 0x76 }}
%}

[scriptable, uuid(b1658370-f4af-4b02-8052-3cfeb7dab10e)]
interface nsIMsgMdnGenerator : nsISupports
{
    const EDisposeType eDisplayed = 0;
    const EDisposeType eDispatched = 1;
    const EDisposeType eProcessed = 2;
    const EDisposeType eDeleted = 3;
    const EDisposeType eDenied = 4;
    const EDisposeType eFailed = 5;
    
    const ReceiptHdrType eDntType = 0;
    const ReceiptHdrType eRrtType = 1;
    const ReceiptHdrType eDntRrtType = 2;
    
    const MDNIncorporateType eIncorporateInbox = 0;
    const MDNIncorporateType eIncorporateSent = 1;
    
    void process(in EDisposeType eType, in nsIMsgWindow aWindow,
                 in nsIMsgFolder folder, in nsMsgKey key, 
                 in nsIMimeHeaders headers, in boolean autoAction);
};
